location property
Only given if the message's type equals "location". An array of two numbers which represent the longitude and latitude of this location, respectively. Only given if this message is a shared location.
Example:
[51.481083, -3.178306]
Implementation
external List<num>? location;