enterSendsMessage property
If set to true, pressing the enter key sends the message (if there is text in the message
field). When set to false, the only way to send a message is by clicking or touching the
"Send" button. Defaults to true.
Implementation
external bool? enterSendsMessage;