launcher property
Specifies whether to show a round launcher and/or close button beneath the popup in the right bottom corner of the page.
@remarks
"close-only": show a close button beneath the popup, but don't show a launch button
"always": show a launch button when the popup is closed, show a close button when it is visible
"never": never show a launcher
Note: if you choose "never" you may want to override the positioning of the popup as well.
Just tune the __talkjs_popup class in your CSS.
Ignored on mobile, where the popup fills the entire screen so the value is effectively "never".
Defaults to "always".
"close-only" | "always" | "never"
Implementation
external String? launcher;