showCloseInHeader property
dynamic
showCloseInHeader
getter/setter pair
Whether to show the "x" icon in the popup header to close the popup.
"auto", which is the default value means true on mobile and to false on desktop.
Implementation
external dynamic /*bool|"auto"|null*/ showCloseInHeader;